@@ -26,11 +26,18 @@ SpeedoMeter::SpeedoMeter(QWidget *parent) :
     ui->lcdNumber->setDigitCount(7);
     ui->lcdNumber_4->setDigitCount(10);
 
-    // load total distance from a file
+    // load total distance and unit setting from a file
     FILE *fp=fopen("/home/user/.speedrec","r");
+    int fileSize;
     if(0!=fp)
     {
+        fseek(fp,0,SEEK_END);
+        fileSize = ftell(fp);
+        rewind(fp);
+
         fscanf(fp,"%f",&total);
+        if(fileSize>=10) // if new .speedrec file
+        fscanf(fp,"%d",&unit);
         fclose(fp);
     }
     hour=min=sec=tensofsec=0;
@@ -50,7 +57,7 @@ SpeedoMeter::~SpeedoMeter()
     FILE *fp=fopen("/home/user/.speedrec","w");
     if(0!=fp)
     {
-        fprintf(fp,"%f",total);
+        fprintf(fp,"%f %d",total,unit);
         fclose(fp);
     }
     stopLocation();
